@@ -10,11 +10,16 @@ has ai => (
         }
 );
 
+has model => (
+	is => 'rw',
+	default => sub { 'text-embedding-3-large' }
+);
+
 sub get {
         my ($self, $data) = @_;
 
         my $res = $self->ai->embeddings(
-                model => 'text-embedding-3-large',
+                model => $self->model,
                 input => $data
         );
 
